window.Gleam.initSearch([{"doc":"probly","title":"probly","content":"# 🎲 probly\n\n[![Package Version](https://img.shields.io/hexpm/v/probly)](https://hex.pm/packages/probly)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/probly/)\n\n## Probabalistic functional programming, without typeclasses\n\nThis library is largely influenced by **Probabilistic Functional Programming in Haskell** by Martin Erwig and Steve Kollmansberger. This implementation adapts the paper&#39;s model to Gleam&#39;s simpler functional interface. See [All you need is data and functions](https://mckayla.blog/posts/all-you-need-is-data-and-functions.html).\n\n## Usage\n\n```sh\ngleam add probly\n```\n\n```gleam\nimport gleam/float\nimport gleam/io\n\nimport probly\n\n// Define a distribution for a fair coin\npub fn main() {\n  // A fair 6-sided die\n  let die = [\n    #(1, 1.0 /. 6.0),\n    #(2, 1.0 /. 6.0),\n    #(3, 1.0 /. 6.0),\n    #(4, 1.0 /. 6.0),\n    #(5, 1.0 /. 6.0),\n    #(6, 1.0 /. 6.0),\n  ]\n\n  // Probability that the die shows a 3\n  let event_3 = fn(x) { x == 3 }\n  let p_3 = probly.probability_of_event(event_3, die)\n  io.println(&quot;Probability of rolling a 3: &quot; &lt;&gt; float.to_string(p_3))\n\n  // Combine two dice\n  let two_dice = probly.combine_dist(die, die)\n\n  // Probability that the sum of the two dice is 7\n  let sum_is_7 = fn(dice: #(Int, Int)) { dice.0 + dice.1 == 7 }\n  let p_sum_7 = probly.probability_of_event(sum_is_7, two_dice)\n  io.println(&quot;Probability sum of two dice = 7: &quot; &lt;&gt; float.to_string(p_sum_7))\n}\n```\n\nFind more examples in `/examples/`, and further documentation at &lt;https://hexdocs.pm/probly&gt;.\n\n## Resources\n\n```\nMartin Erwig and Steve Kollmansberger. 2006. FUNCTIONAL PEARLS: Probabilistic functional programming in Haskell. J. Funct. Program. 16, 1 (January 2006), 21–34. https://doi.org/10.1017/S0956796805005721\n```\n","url":"index.html"},{"doc":"probly","title":"Dist","content":"pub type Dist(a) =\n  List(#(a, Prob))\n Represents the outcome of a probabilistic event as a collection of\n all possible values, tagged with their likelihood.\n\nSynonyms:\nprobly.Dist\nprobly Dist","url":"probly.html#Dist"},{"doc":"probly","title":"Event","content":"pub type Event(a) =\n  fn(a) -&gt; Bool\n Match an entry in a Dist to a given value of type `a`.\n\nSynonyms:\nprobly.Event\nprobly Event","url":"probly.html#Event"},{"doc":"probly","title":"Prob","content":"pub type Prob =\n  Float\n The probability of an event occuring. Within [0, 1].\n\nSynonyms:\nprobly.Prob\nprobly Prob","url":"probly.html#Prob"},{"doc":"probly","title":"Spread","content":"pub type Spread(a) =\n  fn(List(a)) -&gt; Dist(a)\n Functions that &quot;spread&quot; values across distributions by assigning them\n with probabilities. Examples include `uniform` and `binomial`.\n\nSynonyms:\nprobly.Spread\nprobly Spread","url":"probly.html#Spread"},{"doc":"probly","title":"combine_dist","content":"pub fn combine_dist(\n  dist1: List(#(a, Float)),\n  dist2: List(#(b, Float)),\n) -&gt; List(#(#(a, b), Float))\n Combine distributions, assuming independence.\nSynonyms:\nprobly.combine_dist\nprobly combine_dist","url":"probly.html#combine_dist"},{"doc":"probly","title":"combine_dist_normalized","content":"pub fn combine_dist_normalized(\n  dist1: List(#(a, Float)),\n  dist2: List(#(b, Float)),\n) -&gt; List(#(#(a, b), Float))\n Normalize the combinination two `Dist`s.\nSynonyms:\nprobly.combine_dist_normalized\nprobly combine_dist_normalized","url":"probly.html#combine_dist_normalized"},{"doc":"probly","title":"normalize","content":"pub fn normalize(dist: List(#(a, Float))) -&gt; List(#(a, Float))\n Merge duplicates in a distribution by summing probabilities.\n &quot;normalize&quot; is a bit overloaded, this function does not ensure\n that the sum of all probabilities across a Dist is 1.\nSynonyms:\nprobly.normalize\nprobly normalize","url":"probly.html#normalize"},{"doc":"probly","title":"probability_of_event","content":"pub fn probability_of_event(\n  event: fn(a) -&gt; Bool,\n  dist: List(#(a, Float)),\n) -&gt; Float\n Retrieve the probability of an Event within a Dist occuring.\nSynonyms:\nprobly.probability_of_event\nprobly probability_of_event","url":"probly.html#probability_of_event"},{"doc":"probly","title":"probly","content":"","url":"probly.html"}]);